Welcome to ataraxis-transport-layer-pc API documentation page
=============================================================

ataraxis-transport-layer-pc is a Python library that provides methods for establishing and maintaining bidirectional
communication with Arduino and Teensy microcontrollers over USB or UART serial interfaces.

This library is part of the broader 'Ataraxis' science-automation project, developed in the
`Sun Lab <https://neuroai.github.io/sunlab/>`_ at Cornell University. It has a companion library written in C++,
`ataraxis-transport-layer-mc <https://github.com/Sun-Lab-NBB/ataraxis-transport-layer-mc>`_, intended for
Arduino and Teensy microcontrollers participating in the serialized communication over the transport layer.

This website only contains the API documentation for the classes and methods offered by this library. See the project
GitHub repository for installation instructions and library usage examples:
`ataraxis-transport-layer-pc GitHub repository <https://github.com/Sun-Lab-NBB/ataraxis-transport-layer-pc>`_.

.. _`ataraxis-transport-layer-mc`: https://github.com/Sun-Lab-NBB/ataraxis-transport-layer-mc
.. _`ataraxis-transport-layer-pc GitHub repository`: https://github.com/Sun-Lab-NBB/ataraxis-transport-layer-pc
.. _`Sun Lab`: https://neuroai.github.io/sunlab/
